@@ -6,13 +6,16 @@ __license__ = 'GPL 2.0/LGPL 2.1'
 from django.contrib import admin
 from django.contrib.admin import helpers
 from django.utils.translation import ugettext_lazy as _
+from django.utils.html import strip_tags
 from django.contrib.admin.views.decorators import staff_member_required
 from django.utils.decorators import method_decorator
-from django.conf.urls import patterns, url
+from django.conf.urls import url
 from django.shortcuts import render_to_response, redirect
 from django.template import RequestContext
 from django.contrib import messages
 
+from nine.versions import DJANGO_LTE_1_5
+
 from fobi.models import (
     FormElement, FormHandler, FormEntry, FormElementEntry, FormHandlerEntry
     #FormWizardEntry, FormFieldsetEntry,
@@ -114,8 +117,7 @@ class FormEntryAdmin(admin.ModelAdmin):
     """
     Form entry admin.
     """
-    list_display = ('name', 'slug', 'user', 'form_wizard_entry', 'is_public', \
-                    'is_cloneable',)
+    list_display = ('name', 'slug', 'user', 'is_public', 'created', 'updated', 'is_cloneable',)
     list_editable = ('is_public', 'is_cloneable',)
     list_filter = ('is_public', 'is_cloneable',)
     readonly_fields = ('slug',)
@@ -198,11 +200,17 @@ class FormElementEntryAdmin(admin.ModelAdmin):
     class Meta:
         app_label = _('Fobi')
 
-    def queryset(self, request):
-        queryset = super(FormElementEntryAdmin, self).queryset(request)
+    def __queryset(self, request):
+        if DJANGO_LTE_1_5:
+            queryset = super(FormElementEntryAdmin, self).queryset(request)
+        else:
+            queryset = super(FormElementEntryAdmin, self).get_queryset(request)
+
         queryset = queryset.select_related('form_entry', 'form_fieldset_entry')
         return queryset
-    get_queryset = queryset
+    get_queryset = __queryset
+    if DJANGO_LTE_1_5:
+        queryset = __queryset
 
 #admin.site.register(FormElementEntry, FormElementEntryAdmin)
 
@@ -231,11 +239,17 @@ class FormHandlerEntryAdmin(admin.ModelAdmin):
     class Meta:
         app_label = _('Form handler entry')
 
-    def queryset(self, request):
-        queryset = super(FormHandlerEntryAdmin, self).queryset(request)
+    def __queryset(self, request):
+        if DJANGO_LTE_1_5:
+            queryset = super(FormHandlerEntryAdmin, self).queryset(request)
+        else:
+            queryset = super(FormHandlerEntryAdmin, self).get_queryset(request)
+
         queryset = queryset.select_related('form_entry',)
         return queryset
-    get_queryset = queryset
+    get_queryset = __queryset
+    if DJANGO_LTE_1_5:
+        queryset = __queryset
 
 #admin.site.register(FormHandlerEntry, FormHandlerEntryAdmin)
 
@@ -273,11 +287,17 @@ class BasePluginModelAdmin(admin.ModelAdmin):
         """
         return False
 
-    def queryset(self, request):
-        queryset = super(BasePluginModelAdmin, self).queryset(request)
+    def __queryset(self, request):
+        if DJANGO_LTE_1_5:
+            queryset = super(BasePluginModelAdmin, self).queryset(request)
+        else:
+            queryset = super(BasePluginModelAdmin, self).get_queryset(request)
+
         queryset = queryset.prefetch_related('users', 'groups')
         return queryset
-    get_queryset = queryset
+    get_queryset = __queryset
+    if DJANGO_LTE_1_5:
+        queryset = __queryset
 
     def _get_bulk_change_form_class(self):
         raise NotImplemented("You should implement `get_bulk_change_form_class`")
@@ -300,6 +320,7 @@ class BasePluginModelAdmin(admin.ModelAdmin):
                 data = request.POST,
                 files = request.FILES
                 )
+
             if form.is_valid():
                 ids = form.cleaned_data.pop('selected_plugins').split(',')
                 users = form.cleaned_data.pop('users')
@@ -336,6 +357,12 @@ class BasePluginModelAdmin(admin.ModelAdmin):
                     _('{0} plugins were changed successfully.').format(len(ids))
                     )
                 return redirect(changelist_named_url)
+            else:
+                messages.warning(
+                    request,
+                    _('Form contains errors: {}').format(strip_tags(form.errors))
+                    )
+                return redirect(changelist_named_url)
         else:
             messages.warning(
                 request,
@@ -362,11 +389,11 @@ class FormElementAdmin(BasePluginModelAdmin):
         return 'admin:fobi_formelement_changelist'
 
     def get_urls(self):
-        my_urls = patterns('',
+        my_urls = [
             # Bulk change plugins
             url(r'^bulk-change-form-element-plugins/$', self.bulk_change_plugins,
                 name='bulk_change_form_element_plugins'),
-        )
+        ]
         return my_urls + super(FormElementAdmin, self).get_urls()
 
 
@@ -391,11 +418,11 @@ class FormHandlerAdmin(BasePluginModelAdmin):
         return 'admin:fobi_formhandler_changelist'
 
     def get_urls(self):
-        my_urls = patterns('',
+        my_urls = [
             # Bulk change plugins
             url(r'^bulk-change-form-handler-plugins/$', self.bulk_change_plugins,
                 name='bulk_change_form_handler_plugins'),
-        )
+        ]
         return my_urls + super(FormHandlerAdmin, self).get_urls()
 
 
