@@ -2,9 +2,10 @@
 All `uids` are supposed to be pythonic function names (see
 PEP http://www.python.org/dev/peps/pep-0008/#function-names).
 """
+
 __title__ = 'fobi.base'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
+__copyright__ = '2014-2015 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = (
     'BaseDataStorage', 'FormElementPluginDataStorage',
@@ -31,23 +32,33 @@ __all__ = (
     'get_form_element_plugin_widget', 'get_form_handler_plugin_widget'
     )
 
+import traceback
 import logging
 import copy
 import uuid
-import json
+import re
+
+import simplejson as json
 
 try:
     from collections import OrderedDict
 except ImportError as e:
     from ordereddict import OrderedDict
 
-from six import with_metaclass
+from six import with_metaclass, string_types
 
 from django import forms
 from django.forms import ModelForm
-from django.forms.util import ErrorList
 from django.http import Http404
 from django.utils.translation import ugettext_lazy as _
+from django.template import RequestContext, Template
+
+from nine.versions import DJANGO_GTE_1_7
+
+if DJANGO_GTE_1_7:
+    from django.forms.utils import ErrorList
+else:
+    from django.forms.util import ErrorList
 
 from fobi.discover import autodiscover
 from fobi.constants import CALLBACK_STAGES
@@ -63,8 +74,8 @@ from fobi.exceptions import (
     FormElementPluginDoesNotExist, FormHandlerPluginDoesNotExist
 )
 from fobi.helpers import (
-    uniquify_sequence, map_field_name_to_label, clean_dict,
-    map_field_name_to_label, get_ignorable_form_values, safe_text
+    uniquify_sequence, clean_dict, map_field_name_to_label,
+    get_ignorable_form_values, safe_text, StrippedRequest,
 )
 from fobi.data_structures import SortableDict
 
@@ -136,6 +147,7 @@ class BaseTheme(object):
     base_view_template = None
     base_edit_template = None
     form_snippet_template_name = 'fobi/generic/snippets/form_snippet.html'
+    form_wizard_template = 'fobi/generic/snippets/form_wizard.html'
     form_view_snippet_template_name = None
     form_edit_snippet_template_name = None
     form_properties_snippet_template_name = \
@@ -157,6 +169,7 @@ class BaseTheme(object):
     create_form_entry_template = 'fobi/generic/create_form_entry.html'
     create_form_entry_ajax_template = 'fobi/generic/create_form_entry_ajax.html'
     dashboard_template = 'fobi/generic/dashboard.html'
+    forms_list_template = 'fobi/generic/forms_list.html'
     edit_form_element_entry_template = \
         'fobi/generic/edit_form_element_entry.html'
     edit_form_element_entry_ajax_template = \
@@ -175,6 +188,11 @@ class BaseTheme(object):
     view_form_entry_ajax_template = 'fobi/generic/view_form_entry_ajax.html'
     view_embed_form_entry_ajax_template = None
 
+    import_form_entry_template = 'fobi/generic/import_form_entry.html'
+    import_form_entry_ajax_template = 'fobi/generic/import_form_entry_ajax.html'
+    form_importer_template = 'fobi/generic/form_importer.html'
+    form_importer_ajax_template = 'fobi/generic/form_importer_ajax.html'
+
     # *************************************************************************
     # ******************** Extras that make things easy ***********************
     # *************************************************************************
@@ -225,12 +243,14 @@ class BaseTheme(object):
         # If no specific ``form_view_snippet_template_name`` specified, fall
         # back to the ``form_snippet_template_name``.
         if not self.form_view_snippet_template_name:
-            self.form_view_snippet_template_name = self.form_snippet_template_name
+            self.form_view_snippet_template_name = \
+                self.form_snippet_template_name
 
         # If no specific ``form_edit_snippet_template_name`` specified, fall
         # back to the ``form_snippet_template_name``.
         if not self.form_edit_snippet_template_name:
-            self.form_edit_snippet_template_name = self.form_snippet_template_name
+            self.form_edit_snippet_template_name = \
+                self.form_snippet_template_name
 
         # If no specific ``form_view_ajax`` specified, fall
         # back to the ``form_ajax``.
@@ -242,14 +262,16 @@ class BaseTheme(object):
         if not self.form_edit_ajax:
             self.form_edit_ajax = self.form_ajax
 
-        # If no specific ``view_embed_form_entry_ajax_template`` specified, fall
-        # back to the ``view_form_entry_ajax_template``.
+        # If no specific ``view_embed_form_entry_ajax_template`` specified, 
+        # fall back to the ``view_form_entry_ajax_template``.
         if not self.view_embed_form_entry_ajax_template:
-            self.view_embed_form_entry_ajax_template = self.view_form_entry_ajax_template
+            self.view_embed_form_entry_ajax_template = \
+                self.view_form_entry_ajax_template
 
         # Some sort of a embed thank you.
         if not self.embed_form_entry_submitted_ajax_template:
-            self.embed_form_entry_submitted_ajax_template = self.form_entry_submitted_ajax_template
+            self.embed_form_entry_submitted_ajax_template = \
+                self.form_entry_submitted_ajax_template
 
         # Set theme specific data from settings for to be
         # refered like `fobi_theme.custom_data`.
@@ -553,7 +575,9 @@ class BaseFormFieldPluginForm(BasePluginForm):
                 return False
 
             # Make sure field label is unique
-            if hasattr(plugin.data, 'label') and plugin.data.label == data['label']:
+            if hasattr(plugin.data, 'label') and \
+               plugin.data.label == data['label']:
+
                 self._errors.update({'label': [_("Duplicate label name!")]})
                 return False
 
@@ -806,7 +830,8 @@ class BasePlugin(object):
         """
         return self.form
 
-    def get_initialised_create_form(self, data=None, files=None):
+    def get_initialised_create_form(self, data=None, files=None,
+                                    initial_data=None):
         """
         Used ``fobi.views.add_form_element_entry`` and
         ``fobi.views.add_form_handler_entry`` view to gets initialised form
@@ -817,7 +842,13 @@ class BasePlugin(object):
             try:
                 plugin_form = self.get_form()
                 if plugin_form:
-                    return plugin_form(data=data, files=files)
+                    kwargs = {
+                        'data': data,
+                        'files': files,
+                    }
+                    if initial_data:
+                        kwargs.update({'initial': initial_data})
+                    return plugin_form(**kwargs)
             except Exception as e:
                 if DEBUG:
                     logger.debug(e)
@@ -830,16 +861,25 @@ class BasePlugin(object):
         """
         plugin_form = self.get_form()
         if plugin_form:
+            initial_data = {}
             try:
-                return self.get_initialised_create_form(data=data, files=files)
+                initial_data = dict(plugin_form.plugin_data_fields)
+            except Exception as err:
+                pass
+            try:
+                return self.get_initialised_create_form(
+                    data = data,
+                    files = files,
+                    initial_data = initial_data
+                    )
             except Exception as e:
                 if DEBUG:
                     logger.debug(e)
                 raise Http404(e)
 
-    def get_initialised_edit_form(self, data=None, files=None, \
-                                  auto_id='id_%s', prefix=None, initial=None, \
-                                  error_class=ErrorList, label_suffix=':', \
+    def get_initialised_edit_form(self, data=None, files=None,
+                                  auto_id='id_%s', prefix=None, initial=None,
+                                  error_class=ErrorList, label_suffix=':',
                                   empty_permitted=False, instance=None):
         """
         Used in ``fobi.views.edit_form_element_entry`` and
@@ -861,10 +901,10 @@ class BasePlugin(object):
                 kwargs.update({'instance': instance})
             return plugin_form(**kwargs)
 
-    def get_initialised_edit_form_or_404(self, data=None, files=None, \
-                                         auto_id='id_%s', prefix=None, \
-                                         error_class=ErrorList, \
-                                         label_suffix=':', \
+    def get_initialised_edit_form_or_404(self, data=None, files=None,
+                                         auto_id='id_%s', prefix=None,
+                                         error_class=ErrorList,
+                                         label_suffix=':',
                                          empty_permitted=False):
         """
         Same as ``get_initialised_edit_form`` but raises
@@ -1007,7 +1047,9 @@ class BasePlugin(object):
 
         >>> def clone_plugin_data(self, dashboard_entry):
         >>>     cloned_image = clone_file(self.data.image, relative_path=True)
-        >>>     return self.get_cloned_plugin_data(update={'image': cloned_image})
+        >>>     return self.get_cloned_plugin_data(
+        >>>         update={'image': cloned_image}
+        >>>         )
         """
         form = self.get_form()
 
@@ -1085,9 +1127,9 @@ class FormElementPlugin(BasePlugin):
     has_value = False
     is_hidden = False
 
-    def _get_form_field_instances(self, form_element_entry=None, origin=None, \
-                                  kwargs_update_func=None, return_func=None, \
-                                  extra={}):
+    def _get_form_field_instances(self, form_element_entry=None, origin=None,
+                                  kwargs_update_func=None, return_func=None,
+                                  extra={}, request=None):
         """
         Used internally. Do not override this method. Gets the instances of
         form fields, that plugin contains.
@@ -1109,7 +1151,9 @@ class FormElementPlugin(BasePlugin):
         # methods in plugins). In DEBUG mode raise an exception if something
         # goes wrong. Otherwise - skip the element.
         try:
-            form_field_instances = self.get_form_field_instances()
+            form_field_instances = self.get_form_field_instances(
+                request=request
+            )
         except AttributeError as e:
             if DEBUG:
                 raise e
@@ -1121,6 +1165,50 @@ class FormElementPlugin(BasePlugin):
             Widget = None
             if isinstance(Field, (list, tuple)):
                 Field, Widget = Field
+
+            # Consider using context for resolving some variables.
+            # For instance, if user is logged in, ``request.user.username``
+            # as an initial value should put the current users' username
+            # as initial value in the form.
+            if 'initial' in field_kwargs and field_kwargs['initial']:
+                try:
+
+                    # For security reasons we're not using the original request
+                    # here.
+                    stripped_request = StrippedRequest(request)
+                    context = RequestContext(stripped_request)
+
+                    # In order to be sure, that no accidental sensitive data
+                    # is exposed in the forms, we only vales from the
+                    # fobi specific context processor. By automatically
+                    # force-prefixing all dynamic value definitions with
+                    # "fobi_dynamic_values." string. See the docs for
+                    # more ("Dyamic initial values" section).
+                    initial = field_kwargs['initial']
+
+                    # For the moment, only string types are dynamic
+                    if isinstance(initial, string_types):
+                        # Strip down the whitespaces we don't need.
+                        initial = re.sub("{{\s+", "{{", initial)
+                        initial = re.sub("\s+}}", "}}", initial)
+
+                        # Prefix all {{ variable }} occurrences with
+                        # "fobi_dynamic_values." so that there's no risk of
+                        # exposing sensitive data. Further security of
+                        # template context processor variables within
+                        # "fobi_dynamic_values." is a developer responsibility.
+                        initial = re.sub("{{", "{{fobi_dynamic_values.",
+                                         initial)
+                        # Strip loading or executing any complicated template
+                        # tags.
+                        initial = re.sub("{%.*%}", "", initial)
+
+                        field_kwargs['initial'] = \
+                            Template(initial).render(context)
+
+                except Exception as err:
+                    logger.debug(err)
+
             # Data to update field instance kwargs with
             kwargs_update = self.get_origin_kwargs_update_func_results(
                 kwargs_update_func,
@@ -1144,14 +1232,11 @@ class FormElementPlugin(BasePlugin):
 
         return processed_field_instances
 
-    def get_form_field_instances(self):
+    def get_form_field_instances(self, request=None):
         """
         Gets the instances of form fields, that plugin contains.
 
-        :param fobi.models.FormElementEntry form_element_entry: Instance.
-        :param string origin:
-        :param callable kwargs_update_func:
-        :param callable return_func:
+        :param django.http.HttpRequest request:
         :return list: List of Django form field instances.
 
         :example:
@@ -1242,8 +1327,13 @@ class FormFieldPlugin(FormElementPlugin):
 class FormHandlerPlugin(BasePlugin):
     """
     Form handler plugin.
+
+    :property fobi.base.FormHandlerPluginDataStorage storage:
+    :property bool allow_multiple: If set to True, plugin can be used multiple
+        times within (per form). Otherwise - just once.
     """
     storage = FormHandlerPluginDataStorage
+    allow_multiple = True
 
     def _run(self, form_entry, request, form, form_element_entries=None):
         """
@@ -1255,20 +1345,28 @@ class FormHandlerPlugin(BasePlugin):
         :param django.forms.Form form:
         :param iterable form_element_entries: Iterable of
             ``fobi.models.FormElementEntry`` objects.
+        :return tuple:
         """
         # For backwards compatibility.
         if not form_element_entries:
             form_element_entries = form_entry.formelemententry_set.all()[:]
 
         try:
-            self.run(form_entry, request, form, form_element_entries)
-        except Exception as e:
+            response = self.run(form_entry, request, form, form_element_entries)
+            if response:
+                return response
+            else:
+                return (True, None)
+        except Exception as err:
             if FAIL_ON_ERRORS_IN_FORM_HANDLER_PLUGINS:
-                raise e
-            logger.debug(
+                raise err.__class__("Exception: {0}. {1}"
+                                    "".format(str(err), traceback.format_exc()))
+            logger.error(
                 "Error in class {0}. Details: "
-                "{1}".format(self.__class__.__name__, str(e))
+                "{1}. Full trace: {2}".format(self.__class__.__name__, str(err),
+                                              traceback.format_exc())
                 )
+            return (False, err)
 
     def run(self, form_entry, request, form, form_element_entries=None):
         """
@@ -1280,6 +1378,7 @@ class FormHandlerPlugin(BasePlugin):
         :param django.forms.Form form:
         :param iterable form_element_entries: Iterable of
             ``fobi.models.FormElementEntry`` objects.
+        :return mixed: May be a tuple (bool, mixed) or None
         """
         raise NotImplemented(
             "You should implement ``callback`` method in your {1} "
@@ -1628,7 +1727,8 @@ class BasePluginWidgetRegistry(object):
 
         uid = BasePluginWidgetRegistry.namify(cls.theme_uid, cls.plugin_uid)
 
-        # If item has not been forced yet, add/replace its' value in the registry
+        # If item has not been forced yet, add/replace its' value in the
+        # registry.
         if force:
 
             if not uid in self._forced:
@@ -1704,10 +1804,12 @@ theme_registry = ThemeRegistry()
 # Register action plugins by calling form_action_plugin_registry.register()
 form_callback_registry = FormCallbackRegistry()
 
-# Register plugin widgets by calling form_element_plugin_widget_registry.register()
+# Register plugin widgets by calling
+# form_element_plugin_widget_registry.register()
 form_element_plugin_widget_registry = FormElementPluginWidgetRegistry()
 
-# Register plugin widgets by calling form_handler_plugin_widget_registry.register()
+# Register plugin widgets by calling
+# form_handler_plugin_widget_registry.register()
 form_handler_plugin_widget_registry = FormHandlerPluginWidgetRegistry()
 
 # *****************************************************************************
@@ -1718,10 +1820,12 @@ form_handler_plugin_widget_registry = FormHandlerPluginWidgetRegistry()
 
 def ensure_autodiscover():
     """
-    Ensures that plugins are autodiscovered.
+    Ensures that plugins are auto-discovered. The form callbacks registry
+    is intentionally left out, since they will be auto-discovered in
+    any case if other modules are discovered.
     """
-    if not (form_element_plugin_registry._registry \
-            and form_handler_plugin_registry._registry \
+    if not (form_element_plugin_registry._registry
+            and form_handler_plugin_registry._registry
             and theme_registry._registry):
         autodiscover()
 
@@ -1748,10 +1852,8 @@ def assemble_form_field_widget_class(base_class, plugin):
             """
             widget = plugin.get_widget()
             if widget.hasattr('render') and callable(widget.render):
-                #print 'rendered using fobi'
                 return widget.render(name, value, attrs=attrs)
             else:
-                #print 'rendered using standard'
                 super(DeclarativeMetaclass, self).render(
                     name, value, attrs=attrs
                     )
@@ -1767,7 +1869,7 @@ def assemble_form_field_widget_class(base_class, plugin):
 # *********************************** Generic *********************************
 # *****************************************************************************
 
-def get_registered_plugins(registry):
+def get_registered_plugins(registry, as_instances=False):
     """
     Gets a list of registered plugins in a form if tuple (plugin name, plugin
     description). If not yet autodiscovered, autodiscovers them.
@@ -1776,6 +1878,9 @@ def get_registered_plugins(registry):
     """
     ensure_autodiscover()
 
+    if as_instances:
+        return registry._registry
+
     registered_plugins = []
 
     for uid, plugin in registry._registry.items():
@@ -1888,7 +1993,7 @@ def submit_plugin_form_data(form_entry, request, form):
     for form_element_entry in form_entry.formelemententry_set.all():
         # Get the plugin.
         form_element_plugin = form_element_entry.get_plugin(request=request)
-        updated_form = form_element_plugin.submit_plugin_form_data(
+        updated_form = form_element_plugin._submit_plugin_form_data(
             form_entry=form_entry, request=request, form=form
             )
         if updated_form:
@@ -1957,7 +2062,7 @@ def get_field_name_to_label_map(form, keys_to_remove=[], values_to_remove=[]):
     :return dict:
     """
     if not keys_to_remove:
-        keys_to_remove = get_ignorable_form_fields()
+        keys_to_remove = get_ignorable_form_fields([])
 
     if not values_to_remove:
         values_to_remove = get_ignorable_form_values()
@@ -1993,19 +2098,20 @@ def get_processed_form_data(form, form_element_entries):
         get_cleaned_data(form, keys_to_remove, values_to_remove)
         )
 
-def get_registered_form_handler_plugins():
+def get_registered_form_handler_plugins(as_instances=False):
     """
     Gets a list of registered plugins in a form of tuple (plugin name, plugin
     description). If not yet autodiscovered, autodiscovers them.
 
     :return list:
     """
-    return get_registered_plugins(form_handler_plugin_registry)
+    return get_registered_plugins(form_handler_plugin_registry,
+                                  as_instances=as_instances)
 
 def get_registered_form_handler_plugin_uids(flattern=True):
     """
-    Gets a list of registered plugins in a form of tuple (plugin name, plugin
-    description). If not yet autodiscovered, autodiscovers them.
+    Gets a list of UIDs of registered form handler plugins. If not yet
+    autodiscovered, autodiscovers them.
 
     :return list:
     """
@@ -2051,7 +2157,14 @@ def run_form_handlers(form_entry, request, form, form_element_entries=None):
     :param django.http.HttpRequest request:
     :param django.forms.Form form:
     :param iterable form_element_entries:
+    :return tuple: List of success responses, list of error responses
     """
+    # Errors list
+    errors = []
+
+    # Responses of successfully procesessed handlers
+    responses = []
+
     # Getting form handler plugins in their execution order.
     ordered_form_handlers = get_ordered_form_handler_plugins()
 
@@ -2065,16 +2178,26 @@ def run_form_handlers(form_entry, request, form, form_element_entries=None):
     # Iterating through the form handlers in the order
     # specified in the settings.
     for uid, form_handlers in ordered_form_handlers.items():
-        logger.debug("UID: {0}".format(uid))
+        #logger.debug("UID: {0}".format(uid))
         for form_handler in form_handlers:
+            # Get the form handler plugin
             form_handler_plugin = form_handler.get_plugin(request=request)
-            form_handler_plugin._run(
+
+            # Run the form handler
+            success, response = form_handler_plugin._run(
                 form_entry,
                 request,
                 form,
                 form_element_entries
                 )
 
+            if success:
+                responses.append((form_handler_plugin, response))
+            else:
+                errors.append((form_handler_plugin, response))
+
+    return (responses, errors)
+
 # *****************************************************************************
 # ******************************* Theme specific ******************************
 # *****************************************************************************
@@ -2173,7 +2296,7 @@ def fire_form_callbacks(form_entry, request, form, stage=None):
 # *****************************************************************************
 # ******************************* Widget specific *****************************
 # *****************************************************************************
-def get_plugin_widget(registry, plugin_uid, request=None, as_instance=False, \
+def get_plugin_widget(registry, plugin_uid, request=None, as_instance=False,
                       theme=None):
     """
     Gets the plugin widget for the ``plugin_uid`` given. Looks up in the
