@@ -4,9 +4,11 @@ __copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = (
     'ACTION_CHOICE_REPLACE', 'ACTION_CHOICE_APPEND', 'ACTION_CHOICES',
-    'CALLBACK_BEFORE_FORM_VALIDATION', 'CALLBACK_FORM_VALID_BEFORE_SUBMIT_PLUGIN_FORM_DATA',
+    'CALLBACK_BEFORE_FORM_VALIDATION',
+    'CALLBACK_FORM_VALID_BEFORE_SUBMIT_PLUGIN_FORM_DATA',
     'CALLBACK_FORM_VALID', 'CALLBACK_FORM_VALID_AFTER_FORM_HANDLERS',
     'CALLBACK_FORM_INVALID', 'CALLBACK_STAGES',
+    'SUBMIT_VALUE_AS_VAL', 'SUBMIT_VALUE_AS_REPR', 'SUBMIT_VALUE_AS_MIX',
 )
 
 from django.utils.translation import ugettext_lazy as _
@@ -30,3 +32,7 @@ CALLBACK_STAGES = (
     CALLBACK_FORM_INVALID,
     CALLBACK_FORM_VALID_AFTER_FORM_HANDLERS,
 )
+
+SUBMIT_VALUE_AS_VAL = 'val'
+SUBMIT_VALUE_AS_REPR = 'repr'
+SUBMIT_VALUE_AS_MIX = 'mix'
