@@ -4,14 +4,14 @@
 """
 __title__ = 'fobi.contrib.apps.djangocms_integration.settings'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
+__copyright__ = 'Copyright (c) 2014-2015 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = (
     'WIDGET_FORM_SENT_GET_PARAM', 'FORM_TEMPLATE_CHOICES',
     'SUCCESS_PAGE_TEMPLATE_CHOICES',
 )
 
-from fobi.contrib.apps.djangocms_integration.conf import get_setting
+from .conf import get_setting
 
 # **************************************************************
 # **************************************************************
