@@ -1,13 +1,12 @@
 __title__ = 'fobi.contrib.apps.feincms_integration.helpers'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
+__copyright__ = 'Copyright (c) 2014-2015 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('get_form_template_choices', 'get_success_page_template_choices',)
 
 from fobi.integration.helpers import get_template_choices
-from fobi.contrib.apps.feincms_integration.settings import (
-    FORM_TEMPLATE_CHOICES, SUCCESS_PAGE_TEMPLATE_CHOICES
-)
+
+from .settings import FORM_TEMPLATE_CHOICES, SUCCESS_PAGE_TEMPLATE_CHOICES
 
 def get_form_template_choices():
     """
