@@ -1,12 +1,12 @@
 __title__ = 'fobi.contrib.apps.mezzanine_integration.conf'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
+__copyright__ = 'Copyright (c) 2014-2015 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('get_setting',)
 
 from django.conf import settings
 
-from fobi.contrib.apps.mezzanine_integration import defaults
+from . import defaults
 
 def get_setting(setting, override=None):
     """
