@@ -1,18 +1,20 @@
 __title__ = 'fobi.contrib.plugins.form_elements.content.content_text.fobi_form_elements'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
+__copyright__ = 'Copyright (c) 2014-2015 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('ContentTextPlugin',)
 
 from uuid import uuid4
 
 from django.utils.translation import ugettext_lazy as _
+from django.utils.encoding import smart_str
+
+from nonefield.fields import NoneField
 
 from fobi.base import FormElementPlugin, form_element_plugin_registry
-from fobi.fields import NoneField
-from fobi.contrib.plugins.form_elements.content.content_text import UID
-from fobi.contrib.plugins.form_elements.content.content_text.forms \
-    import ContentTextForm
+
+from . import UID
+from .forms import ContentTextForm
 
 class ContentTextPlugin(FormElementPlugin):
     """
@@ -29,12 +31,12 @@ class ContentTextPlugin(FormElementPlugin):
         """
         self.data.name = "{0}_{1}".format(self.uid, uuid4())
 
-    def get_form_field_instances(self):
+    def get_form_field_instances(self, request=None):
         """
         Get form field instances.
         """
         kwargs = {
-            'initial': "<p>{0}</p>".format(self.data.text),
+            'initial': "<p>{0}</p>".format(smart_str(self.data.text)),
             'required': False,
             'label': '',
         }
