@@ -10,11 +10,12 @@ from django.utils.translation import ugettext_lazy as _
 
 from vishap import render_video
 
+from nonefield.fields import NoneField
+
 from fobi.base import FormElementPlugin, form_element_plugin_registry
-from fobi.fields import NoneField
-from fobi.contrib.plugins.form_elements.content.content_video import UID
-from fobi.contrib.plugins.form_elements.content.content_video.forms \
-    import ContentVideoForm
+
+from . import UID
+from .forms import ContentVideoForm
 
 class ContentVideoPlugin(FormElementPlugin):
     """
@@ -31,7 +32,7 @@ class ContentVideoPlugin(FormElementPlugin):
         """
         self.data.name = "{0}_{1}".format(self.uid, uuid4())
 
-    def get_form_field_instances(self):
+    def get_form_field_instances(self, request=None):
         """
         Get form field instances.
         """
