@@ -8,9 +8,9 @@ from django.forms.fields import BooleanField
 from django.utils.translation import ugettext_lazy as _
 
 from fobi.base import FormFieldPlugin, form_element_plugin_registry
-from fobi.contrib.plugins.form_elements.fields.boolean import UID
-from fobi.contrib.plugins.form_elements.fields.boolean.forms \
-    import BooleanSelectForm
+
+from . import UID
+from .forms import BooleanSelectForm
 
 class BooleanSelectPlugin(FormFieldPlugin):
     """
@@ -21,7 +21,7 @@ class BooleanSelectPlugin(FormFieldPlugin):
     group = _("Fields")
     form = BooleanSelectForm
 
-    def get_form_field_instances(self):
+    def get_form_field_instances(self, request=None):
         """
         Get form field instances.
         """
