@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+
 __title__ = 'fobi.contrib.plugins.form_elements.fields.datetime.apps'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
 __copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
@@ -8,7 +10,8 @@ try:
     from django.apps import AppConfig
 
     class Config(AppConfig):
-        name = label = 'fobi.contrib.plugins.form_elements.fields.datetime'
+        name = 'fobi.contrib.plugins.form_elements.fields.datetime'
+        label = 'fobi_contrib_plugins_form_elements_fields_datetime'
 
 except ImportError:
     pass
