@@ -4,4 +4,6 @@ __copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('FILES_UPLOAD_DIR',)
 
-FILES_UPLOAD_DIR = 'fobi_plugins/file'
+import os
+
+FILES_UPLOAD_DIR = os.path.join('fobi_plugins', 'file')
