@@ -8,6 +8,6 @@ __copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('FILES_UPLOAD_DIR',)
 
-from fobi.contrib.plugins.form_elements.fields.file.conf import get_setting
+from .conf import get_setting
 
 FILES_UPLOAD_DIR = get_setting('FILES_UPLOAD_DIR')
