@@ -9,10 +9,9 @@ from django.forms.widgets import HiddenInput#, TextInput
 from django.utils.translation import ugettext_lazy as _
 
 from fobi.base import FormFieldPlugin, form_element_plugin_registry, get_theme
-from fobi.contrib.plugins.form_elements.fields.hidden import UID
-from fobi.contrib.plugins.form_elements.fields.hidden.forms import (
-    HiddenInputForm
-    )
+
+from . import UID
+from .forms import HiddenInputForm
 
 theme = get_theme(request=None, as_instance=True)
 
@@ -26,7 +25,7 @@ class HiddenInputPlugin(FormFieldPlugin):
     form = HiddenInputForm
     is_hidden = True
 
-    def get_form_field_instances(self):
+    def get_form_field_instances(self, request=None):
         """
         Get form field instances.
         """
