@@ -9,8 +9,9 @@ from django.forms.widgets import TextInput
 from django.utils.translation import ugettext_lazy as _
 
 from fobi.base import FormFieldPlugin, form_element_plugin_registry, get_theme
-from fobi.contrib.plugins.form_elements.fields.input import UID
-from fobi.contrib.plugins.form_elements.fields.input.forms import InputForm
+
+from . import UID
+from .forms import InputForm
 
 theme = get_theme(request=None, as_instance=True)
 
@@ -23,7 +24,7 @@ class InputPlugin(FormFieldPlugin):
     group = _("Fields")
     form = InputForm
 
-    def get_form_field_instances(self):
+    def get_form_field_instances(self, request=None):
         """
         Get form field instances.
         """
@@ -66,8 +67,11 @@ class InputPlugin(FormFieldPlugin):
         if self.data.step_value:
             widget_attrs.update({'step': self.data.step_value})
 
+        if self.data.type_value and self.data.type_value in ('submit', 'button', 'reset',):
+            widget_attrs.update({'value': self.data.label})
+
         kwargs = {
-            'label': self.data.label,
+            'label': self.data.label if self.data.type_value not in ('submit', 'button', 'reset',) else '',
             'help_text': self.data.help_text,
             'initial': self.data.initial,
             'required': self.data.required,
