@@ -1,6 +1,6 @@
 __title__ = 'fobi.contrib.plugins.form_elements.fields.select_multiple.forms'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
+__copyright__ = '2014-2015 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('SelectMultipleInputForm',)
 
@@ -8,12 +8,13 @@ from django import forms
 from django.utils.translation import ugettext_lazy as _
 
 from fobi.base import BaseFormFieldPluginForm, get_theme
+from fobi.helpers import validate_initial_for_multiple_choices
 
 theme = get_theme(request=None, as_instance=True)
 
 class SelectMultipleInputForm(forms.Form, BaseFormFieldPluginForm):
     """
-    Form for ``TextInputPlugin``.
+    Form for ``SelectMultipleInputPlugin``.
     """
     plugin_data_fields = [
         ("label", ""),
@@ -68,5 +69,11 @@ class SelectMultipleInputForm(forms.Form, BaseFormFieldPluginForm):
     required = forms.BooleanField(
         label = _("Required"),
         required = False,
-        widget = forms.widgets.CheckboxInput(attrs={'class': theme.form_element_html_class})
+        widget = forms.widgets.CheckboxInput(attrs={'class': theme.form_element_checkbox_html_class})
         )
+
+    def clean_initial(self):
+        """
+        Validating the initial value.
+        """
+        return validate_initial_for_multiple_choices(self, 'choices', 'initial')
