@@ -1,7 +1,11 @@
 __title__ = 'fobi.contrib.plugins.form_elements.fields.select_multiple_model_objects.default'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
+__copyright__ = 'Copyright (c) 2014-2015 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('IGNORED_MODELS',)
+__all__ = ('IGNORED_MODELS', 'SUBMIT_VALUE_AS',)
+
+from fobi.constants import SUBMIT_VALUE_AS_MIX
 
 IGNORED_MODELS = []
+
+SUBMIT_VALUE_AS = SUBMIT_VALUE_AS_MIX
