@@ -1,6 +1,6 @@
 __title__ = 'fobi.contrib.plugins.form_elements.fields.select_multiple_model_objects.forms'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
+__copyright__ = 'Copyright (c) 2014-2015 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('SelectMultipleModelObjectsInputForm',)
 
@@ -9,8 +9,8 @@ from django.utils.translation import ugettext_lazy as _
 
 from fobi.base import BaseFormFieldPluginForm, get_theme
 from fobi.helpers import get_registered_models
-from fobi.contrib.plugins.form_elements.fields.select_multiple_model_objects.settings \
-    import IGNORED_MODELS
+
+from .settings import IGNORED_MODELS
 
 theme = get_theme(request=None, as_instance=True)
 
@@ -56,7 +56,7 @@ class SelectMultipleModelObjectsInputForm(forms.Form, BaseFormFieldPluginForm):
     required = forms.BooleanField(
         label = _("Required"),
         required = False,
-        widget = forms.widgets.CheckboxInput(attrs={'class': theme.form_element_html_class})
+        widget = forms.widgets.CheckboxInput(attrs={'class': theme.form_element_checkbox_html_class})
         )
 
     def __init__(self, *args, **kwargs):
@@ -66,4 +66,4 @@ class SelectMultipleModelObjectsInputForm(forms.Form, BaseFormFieldPluginForm):
         super(SelectMultipleModelObjectsInputForm, self).__init__(*args, **kwargs)
         self.fields['model'].choices = get_registered_models(
             ignore = IGNORED_MODELS
-            )
\ No newline at end of file
+            )
