@@ -16,8 +16,9 @@ except ImportError:
 from django.utils.translation import ugettext_lazy as _
 
 from fobi.base import FormFieldPlugin, form_element_plugin_registry, get_theme
-from fobi.contrib.plugins.form_elements.fields.url import UID
-from fobi.contrib.plugins.form_elements.fields.url.forms import URLInputForm
+
+from . import UID
+from .forms import URLInputForm
 
 theme = get_theme(request=None, as_instance=True)
 
@@ -30,7 +31,7 @@ class URLInputPlugin(FormFieldPlugin):
     group = _("Fields")
     form = URLInputForm
 
-    def get_form_field_instances(self):
+    def get_form_field_instances(self, request=None):
         """
         Get form field instances.
         """
