@@ -22,7 +22,7 @@ class HoneypotInputForm(forms.Form, BaseFormFieldPluginForm):
         #("help_text", ""),
         ("initial", ""),
         ("max_length", "255"),
-        ("required", False),
+        ("required", True),
         #("placeholder", ""),
     ]
 
@@ -55,7 +55,7 @@ class HoneypotInputForm(forms.Form, BaseFormFieldPluginForm):
     required = forms.BooleanField(
         label = _("Required"),
         required = False,
-        widget = forms.widgets.CheckboxInput(attrs={'class': theme.form_element_html_class})
+        widget = forms.widgets.CheckboxInput(attrs={'class': theme.form_element_checkbox_html_class})
         )
     #placeholder = forms.CharField(
     #    label = _("Placeholder"),
