@@ -8,10 +8,12 @@ from uuid import uuid4
 
 from django.utils.translation import ugettext, ugettext_lazy as _
 
+from nonefield.fields import NoneField
+
 from fobi.base import FormElementPlugin, form_element_plugin_registry
-from fobi.fields import NoneField
 from fobi.helpers import safe_text
-from fobi.contrib.plugins.form_elements.test.dummy import UID
+
+from . import UID
 
 class DummyPlugin(FormElementPlugin):
     """
@@ -27,7 +29,7 @@ class DummyPlugin(FormElementPlugin):
         """
         self.data.name = "{0}_{1}".format(self.uid, uuid4())
 
-    def get_form_field_instances(self):
+    def get_form_field_instances(self, request=None):
         """
         Get form field instances.
         """
