@@ -4,6 +4,6 @@ __copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('default_app_config', 'UID',)
 
-#default_app_config = 'fobi.contrib.plugins.form_handlers.db_store.apps.Config'
+default_app_config = 'fobi.contrib.plugins.form_handlers.db_store.apps.Config'
 
 UID = 'db_store'
