@@ -4,9 +4,11 @@ __copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('DBStoreHandlerPlugin',)
 
-import json
+#import json
 import datetime
 
+import simplejson as json
+
 from django.utils.translation import ugettext_lazy as _
 from django.core.urlresolvers import reverse
 
@@ -14,14 +16,17 @@ from fobi.base import (
     FormHandlerPlugin, form_handler_plugin_registry, get_processed_form_data,
     get_form_handler_plugin_widget
 )
-from fobi.contrib.plugins.form_handlers.db_store import UID
-from fobi.contrib.plugins.form_handlers.db_store.models import (
-    SavedFormDataEntry
-)
+
+from . import UID
+from .models import SavedFormDataEntry
 
 class DBStoreHandlerPlugin(FormHandlerPlugin):
+    """
+    DB store form handler plugin. Can be used only once per form.
+    """
     uid = UID
     name = _("DB store")
+    allow_multiple = False
 
     def run(self, form_entry, request, form, form_element_entries=None):
         """
