@@ -8,7 +8,8 @@ try:
     from django.apps import AppConfig
 
     class Config(AppConfig):
-        name = label = 'fobi.contrib.plugins.form_importers.mailchimp_importer'
+        name = 'fobi.contrib.plugins.form_importers.mailchimp_importer'
+        label = 'fobi_contrib_plugins_form_importers_mailchimp_importer'
 
 except ImportError:
     pass
