@@ -7,7 +7,8 @@ __all__ = ('Foundation5Theme',)
 from django.utils.translation import ugettext_lazy as _
 
 from fobi.base import BaseTheme, theme_registry
-from fobi.contrib.themes.foundation5 import UID
+
+from . import UID
 
 class Foundation5Theme(BaseTheme):
     """
@@ -85,6 +86,7 @@ class Foundation5Theme(BaseTheme):
     create_form_entry_ajax_template = 'foundation5/create_form_entry_ajax.html'
 
     dashboard_template = 'foundation5/dashboard.html'
+    forms_list_template = 'foundation5/forms_list.html'
 
     edit_form_element_entry_template = 'foundation5/edit_form_element_entry.html'
     edit_form_element_entry_ajax_template = \
@@ -104,5 +106,8 @@ class Foundation5Theme(BaseTheme):
     view_form_entry_template = 'foundation5/view_form_entry.html'
     view_form_entry_ajax_template = 'foundation5/view_form_entry_ajax.html'
 
+    import_form_entry_template = 'foundation5/import_form_entry.html'
+    import_form_entry_ajax_template = 'foundation5/import_form_entry_ajax.html'
+
 
 theme_registry.register(Foundation5Theme)
