@@ -6,7 +6,7 @@ __all__ = (
     'RESTRICT_PLUGIN_ACCESS', 'FORM_ELEMENT_PLUGINS_MODULE_NAME',
     'FORM_HANDLER_PLUGINS_MODULE_NAME', 'FORM_IMPORTER_PLUGINS_MODULE_NAME',
     'FORM_CALLBACKS_MODULE_NAME', 'THEMES_MODULE_NAME', 'DEFAULT_THEME',
-    'DISPLAY_AUTH_LINK', 'DEBUG',
+    'DISPLAY_AUTH_LINK', 'DEBUG', 'GET_PARAM_INITIAL_DATA',
 
     'CUSTOM_THEME_DATA', 'THEME_FOOTER_TEXT',
 
@@ -52,6 +52,9 @@ THEMES_MODULE_NAME = 'fobi_themes'
 # Default theme
 DEFAULT_THEME = 'bootstrap3'
 
+# GET param to tell whether initial data shall be loaded.
+GET_PARAM_INITIAL_DATA = 'fobi_initial_data'
+
 DISPLAY_AUTH_LINK = True
 
 DEBUG = False
