@@ -5,12 +5,15 @@ __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = (
     'FormEntryForm', 'FormFieldsetEntryForm', 'FormElementEntryFormSet',
     'BulkChangeFormElementPluginsForm', 'BulkChangeFormHandlerPluginsForm',
+    'ImportFormEntryForm',
 )
 
+from six.moves.urllib.parse import urlparse
+import socket
+
 from django.forms.models import modelformset_factory
 from django import forms
-from django.utils.translation import ugettext_lazy as _
-
+from django.utils.translation import ugettext, ugettext_lazy as _
 from fobi.models import (
     # Plugins
     FormElement, FormHandler,
@@ -20,6 +23,8 @@ from fobi.models import (
     )
 from fobi.constants import ACTION_CHOICES
 from fobi.base import get_theme
+from fobi.validators import url_exists
+from fobi.exceptions import ImproperlyConfigured
 
 # *****************************************************************************
 # *****************************************************************************
@@ -37,6 +42,13 @@ class FormEntryForm(forms.ModelForm):
                   'success_page_message', 'action',) #'is_cloneable',
 
     def __init__(self, *args, **kwargs):
+        self.request = kwargs.pop('request', None)
+        if self.request is None:
+            raise ImproperlyConfigured(
+                ugettext("The {0} form requires a "
+                         "request argument.".format(self.__class__.__name__))
+                )
+
         super(FormEntryForm, self).__init__(*args, **kwargs)
         theme = get_theme(request=None, as_instance=True)
 
@@ -66,6 +78,44 @@ class FormEntryForm(forms.ModelForm):
         #    attrs={'data-customforms': 'disabled'}
         #    )
 
+    def clean_action(self):
+        """
+        Validate the action (URL). Checks if URL exists.
+        """
+        url = self.cleaned_data['action']
+        if url:
+            full_url = url
+
+            if not (url.startswith('http://') or url.startswith('https://')):
+                full_url = self.request.build_absolute_uri(url)
+
+            parsed_url = urlparse(full_url)
+
+            local = False
+
+            try:
+                localhost = socket.gethostbyname('localhost')
+            except Exception as err:
+                localhost = '127.0.0.1'
+
+            try:
+                host = socket.gethostbyname(parsed_url.hostname)
+
+                local = (localhost == host)
+            except socket.gaierror as err:
+                pass
+
+            if local:
+                full_url = parsed_url.path
+
+            if not url_exists(full_url, local=local):
+                raise forms.ValidationError(
+                    ugettext("Invalid action URL {0}.").format(full_url)
+                    )
+
+        return url
+
+
 class FormFieldsetEntryForm(forms.ModelForm):
     """
     Form for ``fobi.models.FormFieldsetEntry`` model.
@@ -75,7 +125,7 @@ class FormFieldsetEntryForm(forms.ModelForm):
         fields = ('name',)
 
     def __init__(self, *args, **kwargs):
-        super(FormFieldsetEntry, self).__init__(*args, **kwargs)
+        super(FormFieldsetEntryForm, self).__init__(*args, **kwargs)
         theme = get_theme(request=None, as_instance=True)
         self.fields['name'].widget = forms.widgets.TextInput(
             attrs={'class': theme.form_element_html_class}
@@ -97,14 +147,14 @@ class BaseBulkChangePluginsForm(forms.ModelForm):
     """
     Bulk change plugins form.
 
-    - `selected_dashboard_plugins` (str): List of comma separated values to be
+    - `selected_plugins` (str): List of comma separated values to be
        changed.
     - `users_action` (int): For indicating wheither the users shall be appended
       to the dashbard plugins or replaced.
     - `groups_action` (int): For indicating wheither the groups shall be
       appended to the dashboard plugins or replaced.
     """
-    selected_dashboard_plugins = forms.CharField(
+    selected_plugins = forms.CharField(
         required=True, label=_("Selected plugins"),
         widget=forms.widgets.HiddenInput
         )
@@ -148,3 +198,21 @@ class BulkChangeFormHandlerPluginsForm(BaseBulkChangePluginsForm):
     class Meta:
         model = FormHandler
         fields = ['groups', 'groups_action', 'users', 'users_action',]
+
+# *****************************************************************************
+# *****************************************************************************
+# **************************** Import form entry ******************************
+# *****************************************************************************
+# *****************************************************************************
+
+class ImportFormEntryForm(forms.Form):
+    """
+    Import form entry form.
+    """
+    file = forms.FileField(required=True, label=_("File"))
+    # ignore_broken_form_element_entries = forms.BooleanField(
+    #     required=False,
+    #     label=_("Ignore broken form element entries"))
+    # ignore_broken_form_handler_entries = forms.BooleanField(
+    #     required=False,
+    #     label=_("Ignore broken form handler entries"))
