@@ -22,6 +22,7 @@ from fobi.constants import (
     CALLBACK_FORM_VALID_AFTER_FORM_HANDLERS
     )
 from fobi.exceptions import ImproperlyConfigured
+from fobi.settings import GET_PARAM_INITIAL_DATA
 
 class IntegrationProcessor(object):
     """
@@ -96,7 +97,8 @@ class IntegrationProcessor(object):
         # dynamically.
         FormClass = assemble_form_class(
             instance.form_entry,
-            form_element_entries = form_element_entries
+            form_element_entries = form_element_entries,
+            request = request
             )
 
         if 'POST' == request.method:
@@ -175,7 +177,13 @@ class IntegrationProcessor(object):
                     )
 
         else:
-            form = FormClass()
+            # Providing initial form data by feeding entire GET dictionary
+            # to the form, if ``GET_PARAM_INITIAL_DATA`` is present in the
+            # GET.
+            kwargs = {}
+            if GET_PARAM_INITIAL_DATA in request.GET:
+                kwargs = {'initial': request.GET}
+            form = FormClass(**kwargs)
 
         theme = get_theme(request=request, as_instance=True)
         theme.collect_plugin_media(form_element_entries)
