@@ -22,7 +22,7 @@ __all__ = (
     'RESTRICT_PLUGIN_ACCESS', 'FORM_ELEMENT_PLUGINS_MODULE_NAME',
     'FORM_HANDLER_PLUGINS_MODULE_NAME', 'FORM_IMPORTER_PLUGINS_MODULE_NAME',
     'FORM_CALLBACKS_MODULE_NAME', 'THEMES_MODULE_NAME', 'DEFAULT_THEME',
-    'DISPLAY_AUTH_LINK', 'DEBUG',
+    'DISPLAY_AUTH_LINK', 'DEBUG', 'GET_PARAM_INITIAL_DATA',
 
     'CUSTOM_THEME_DATA', 'THEME_FOOTER_TEXT',
 
@@ -62,6 +62,8 @@ DEFAULT_THEME = get_setting('DEFAULT_THEME')
 
 DISPLAY_AUTH_LINK = get_setting('DISPLAY_AUTH_LINK')
 
+GET_PARAM_INITIAL_DATA = get_setting('GET_PARAM_INITIAL_DATA')
+
 if not DEFAULT_THEME:
     raise NoDefaultThemeSet("No default theme set!")
 
